
import paramiko
import console
import sys
import keychain

'''
This script is intended to be called from another script. 

'''


def execute(sshComputer, sshPort, kcService, sshUser, sshCommand):
	'''
	Connects through SSH to the Computer/Server passed as an argument, runs as command and disconnects. 
	Arguments:
		
		sshComputer: IP of the computer/server.
		sshPort: ssh open port in computer/server.
		kcService: Service name in Keychain.
		sshUser: computer/server username to establish ssh connection. Important: it should be the same 
		username stored in the Keychain.
		sshCommand: command to run in remote computer.
		
	The script makes use of the keychain Pythonista module to access the password for the 
	sshComputer so it's not left out in the open. Therefore, that password should be manually 
	saved in the Keychain using the Keychain_Handler script.
	'''
	
	#Constants
	print ('Configuring parameters...')
	sshPwd = keychain.get_password(kcService, sshUser)
	
	if not sshPwd:
		print ('Password for '+sshUser+' not found in Keychain. Aborting.')
		return
		
	print ('Password successfully pulled from Keychain.')
	
	
	# Initialize connection
	print ('Initiating SSH connection...')
	client = paramiko.SSHClient()
	client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
	client.connect(hostname=sshComputer, username=sshUser, password=sshPwd, port=sshPort)
	print ('SSH connection established with ' + sshComputer + ' as user ' + sshUser + '.')
	 
	print ('Executing command [' + sshCommand + ']...')
	stdin, stdout, stderr = client.exec_command(sshCommand)
	print (stdout.read())
	print ('Command execution complete.')
	 
	#Close the connection
	print ('Closing SSH connection...')
	client.close()
	print ('SSH connection closed.')
	
	return
	
#execute('sweet-cloud-of.mine.nu', 447, 'Jadeite', 'lenin', 'ls -al')


